@@ -24,10 +24,9 @@
 #ifndef __EMPATHY_AVATAR_CHOOSER_H__
 #define __EMPATHY_AVATAR_CHOOSER_H__
 
+#include <gio/gio.h>
 #include <gtk/gtk.h>
 
-#include <libempathy/empathy-contact.h>
-
 G_BEGIN_DECLS
 
 #define EMPATHY_TYPE_AVATAR_CHOOSER        (empathy_avatar_chooser_get_type ())
