@@ -20,10 +20,7 @@
  *          Danielle Madeley <danielle.madeley@collabora.co.uk>
  */
 
-#include <config.h>
-
-#include <string.h>
-#include <stdlib.h>
+#include "config.h"
 
 #include <glib/gi18n-lib.h>
 
