@@ -18,19 +18,12 @@
  * Authors: Guillaume Desmottes <guillaume.desmottes@collabora.co.uk>
  */
 
-#include <config.h>
+#include "config.h"
 
-#include <string.h>
-#include <stdlib.h>
-
-#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 
-#include <telepathy-glib/telepathy-glib.h>
-
 #include <libempathy/empathy-camera-monitor.h>
 #include <libempathy/empathy-utils.h>
-#include <libempathy/empathy-request-util.h>
 
 #define DEBUG_FLAG EMPATHY_DEBUG_CONTACT
 #include <libempathy/empathy-debug.h>
@@ -40,7 +33,6 @@
 #include <libempathy-gtk/empathy-images.h>
 
 #include "empathy-new-call-dialog.h"
-#include "empathy-account-chooser.h"
 #include "empathy-call-utils.h"
 
 static EmpathyNewCallDialog *dialog_singleton = NULL;
