@@ -20,11 +20,7 @@
  *          Jonny Lamb <jonny.lamb@collabora.co.uk>
  */
 
-#include <config.h>
-
-#include <string.h>
-
-#include <gtk/gtk.h>
+#include "config.h"
 
 #include <glib/gi18n-lib.h>
 
