@@ -5,15 +5,10 @@
 #include <libempathy-gtk/egg-list-box/egg-list-box.h>
 #include <libempathy-gtk/empathy-live-search.h>
 
-#include <libempathy/empathy-individual-manager.h>
 #include <libempathy-gtk/empathy-roster-model.h>
 
 G_BEGIN_DECLS
 
-#define EMPATHY_ROSTER_VIEW_GROUP_UNGROUPED _("Ungrouped")
-#define EMPATHY_ROSTER_VIEW_GROUP_TOP_GROUP _("Top Contacts")
-#define EMPATHY_ROSTER_VIEW_GROUP_PEOPLE_NEARBY _("People Nearby")
-
 typedef struct _EmpathyRosterView EmpathyRosterView;
 typedef struct _EmpathyRosterViewClass EmpathyRosterViewClass;
 typedef struct _EmpathyRosterViewPriv EmpathyRosterViewPriv;
@@ -55,11 +50,7 @@ GType empathy_roster_view_get_type (void);
     EMPATHY_TYPE_ROSTER_VIEW, \
     EmpathyRosterViewClass))
 
-GtkWidget * empathy_roster_view_new (EmpathyIndividualManager *manager,
-    EmpathyRosterModel *model);
-
-EmpathyIndividualManager * empathy_roster_view_get_manager (
-    EmpathyRosterView *self);
+GtkWidget * empathy_roster_view_new (EmpathyRosterModel *model);
 
 void empathy_roster_view_show_offline (EmpathyRosterView *self,
     gboolean show);
