@@ -18,14 +18,11 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "empathy-tls-dialog.h"
 
 #include <glib/gi18n-lib.h>
-#include <gcr/gcr.h>
-#include <telepathy-glib/telepathy-glib.h>
-
 #include <gcr/gcr.h>
 
 #define DEBUG_FLAG EMPATHY_DEBUG_TLS
