@@ -29,13 +29,24 @@ G_BEGIN_DECLS
 
 typedef enum {
     EMPATHY_WEBKIT_MENU_CLEAR = 1 << 0,
+    EMPATHY_WEBKIT_MENU_INSPECT = 1 << 1,
 } EmpathyWebKitMenuFlags;
 
-EmpathyStringParser *empathy_webkit_get_string_parser (gboolean smileys);
+EmpathyStringParser * empathy_webkit_get_string_parser (gboolean smileys);
+
 void empathy_webkit_bind_font_setting (WebKitWebView *webview,
-    GSettings *gsettings, const char *key);
+    GSettings *gsettings,
+    const char *key);
+
+GtkWidget * empathy_webkit_create_context_menu (WebKitWebView *view,
+    WebKitHitTestResult *hit_test_result,
+    EmpathyWebKitMenuFlags flags);
+
 void empathy_webkit_context_menu_for_event (WebKitWebView *view,
-    GdkEventButton *event, EmpathyWebKitMenuFlags flags);
+    GdkEventButton *event,
+    EmpathyWebKitMenuFlags flags);
+
+void empathy_webkit_show_inspector (WebKitWebView *view);
 
 G_END_DECLS
 
