@@ -18,16 +18,12 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "empathy-connection-aggregator.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include "empathy-debug.h"
-#include "empathy-utils.h"
-
-
-#include "extensions/extensions.h"
 
 G_DEFINE_TYPE (EmpathyConnectionAggregator, empathy_connection_aggregator,
     G_TYPE_OBJECT);
