@@ -20,16 +20,7 @@
  *          Travis Reitter <travis.reitter@collabora.co.uk>
  */
 
-#include <config.h>
-
-#include <string.h>
-
-#include <telepathy-glib/telepathy-glib.h>
-
-#include <folks/folks.h>
-#include <folks/folks-telepathy.h>
-
-#include <extensions/extensions.h>
+#include "config.h"
 
 #include "empathy-individual-manager.h"
 #include "empathy-utils.h"
