@@ -18,12 +18,9 @@
  * Authors: Guillaume Desmottes <gdesmott@gnome.org>
  */
 
-#include <config.h>
-#include <string.h>
-#include <sys/types.h>
+#include "config.h"
+
 #include <sys/stat.h>
-#include <libxml/parser.h>
-#include <libxml/tree.h>
 
 #include "empathy-utils.h"
 #include "empathy-irc-network-manager.h"
