@@ -19,13 +19,7 @@
  * Authors: Guillaume Desmottes <gdesmott@gnome.org>
  */
 
-#include <config.h>
-#include <string.h>
-#include <stdlib.h>
-#include <glib.h>
-#include <glib/gi18n-lib.h>
-
-#include <telepathy-glib/telepathy-glib.h>
+#include "config.h"
 
 #include "empathy-irc-network.h"
 #include "empathy-utils.h"
