@@ -19,10 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <config.h>
-
-#include <gnutls/gnutls.h>
-#include <gnutls/x509.h>
+#include "config.h"
 
 #include "empathy-tls-verifier.h"
 
