@@ -19,22 +19,15 @@
  * Authors: Cosimo Cecchi <cosimo.cecchi@collabora.co.uk>
  */
 
-#include <config.h>
+#include "config.h"
 
-#include <stdlib.h>
-#include <glib.h>
 #include <glib/gi18n.h>
-#include <gtk/gtk.h>
-
-#include <telepathy-glib/telepathy-glib.h>
 
 #define DEBUG_FLAG EMPATHY_DEBUG_TLS
 #include <libempathy/empathy-debug.h>
 #include <libempathy/empathy-auth-factory.h>
-#include <libempathy/empathy-server-sasl-handler.h>
 #include <libempathy/empathy-server-tls-handler.h>
 #include <libempathy/empathy-tls-verifier.h>
-#include <libempathy/empathy-utils.h>
 
 #include <libempathy-gtk/empathy-bad-password-dialog.h>
 #include <libempathy-gtk/empathy-password-dialog.h>
@@ -45,8 +38,6 @@
 
 #include <gnutls/gnutls.h>
 
-#include <extensions/extensions.h>
-
 #define TIMEOUT 60
 
 static gboolean use_timer = TRUE;
