@@ -20,11 +20,9 @@
  *          Guillaume Desmottes <guillaume.desmottes@collabora.co.uk>
  */
 
-#include <config.h>
+#include "config.h"
 
-#include <glib.h>
 #include <glib/gi18n.h>
-#include <gtk/gtk.h>
 
 #include <libnotify/notify.h>
 
