@@ -19,18 +19,10 @@
  * Authors: Jonny Lamb <jonny.lamb@collabora.co.uk>
  * */
 
-#include <config.h>
+#include "config.h"
 
-#include <string.h>
-#include <unistd.h>
-
-#include <glib.h>
 #include <glib/gstdio.h>
 #include <dbus/dbus-protocol.h>
-#include <libxml/parser.h>
-#include <libxml/tree.h>
-
-#include <telepathy-glib/telepathy-glib.h>
 
 #include "empathy-import-utils.h"
 #include "empathy-import-pidgin.h"
@@ -39,8 +31,6 @@
 #include <libempathy/empathy-debug.h>
 #include <libempathy/empathy-utils.h>
 
-#include <libempathy-gtk/empathy-ui-utils.h>
-
 /* Pidgin to CM map */
 typedef struct
 {
