@@ -22,21 +22,17 @@
 
 /* empathy-import-widget.c */
 
-#include <config.h>
+#include "config.h"
 
 #include "empathy-import-dialog.h"
 #include "empathy-import-widget.h"
-#include "empathy-import-pidgin.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include <libempathy/empathy-debug.h>
-#include <libempathy/empathy-connection-managers.h>
 #include <libempathy/empathy-utils.h>
 
 #include <libempathy-gtk/empathy-ui-utils.h>
 
-#include <telepathy-glib/telepathy-glib.h>
-
 #include <glib/gi18n-lib.h>
 
 G_DEFINE_TYPE (EmpathyImportWidget, empathy_import_widget, G_TYPE_OBJECT)
