@@ -17,16 +17,13 @@
  *
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <gtk/gtk.h>
-
-#include <pulse/pulseaudio.h>
 #include <pulse/glib-mainloop.h>
 
 #include "empathy-mic-monitor.h"
 
-
 #include <libempathy/empathy-utils.h>
 
 #define DEBUG_FLAG EMPATHY_DEBUG_VOIP
