@@ -19,17 +19,10 @@
  * Authors: Xavier Claessens <xclaesse@gmail.com>
  */
 
-#include <config.h>
+#include "config.h"
 
-#include <stdlib.h>
-#include <errno.h>
-#include <string.h>
-
-#include <glib.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
-#include <gtk/gtk.h>
-#include <gdk/gdkx.h>
 
 #ifdef HAVE_LIBCHAMPLAIN
 #include <clutter-gtk/clutter-gtk.h>
@@ -37,25 +30,17 @@
 
 #include <libnotify/notify.h>
 
-#include <telepathy-glib/telepathy-glib.h>
-
-#include <telepathy-logger/telepathy-logger.h>
-
 #include <libempathy/empathy-client-factory.h>
 #include <libempathy/empathy-connection-aggregator.h>
 #include <libempathy/empathy-presence-manager.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-chatroom-manager.h>
-#include <libempathy/empathy-account-settings.h>
-#include <libempathy/empathy-connection-managers.h>
 #include <libempathy/empathy-request-util.h>
 #include <libempathy/empathy-ft-factory.h>
 #include <libempathy/empathy-gsettings.h>
-#include <libempathy/empathy-tp-chat.h>
 
 #include <libempathy-gtk/empathy-ui-utils.h>
 #include <libempathy-gtk/empathy-location-manager.h>
-#include <libempathy-gtk/empathy-notify-manager.h>
 
 #include "empathy-roster-window.h"
 #include "empathy-accounts-common.h"
@@ -64,8 +49,6 @@
 #include "empathy-ft-manager.h"
 #include "empathy-notifications-approver.h"
 
-#include "extensions/extensions.h"
-
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include <libempathy/empathy-debug.h>
 
@@ -371,11 +354,17 @@ empathy_app_command_line (GApplication *app,
     }
 
   if (self->show_preferences)
-    empathy_roster_window_show_preferences (
-        EMPATHY_ROSTER_WINDOW (self->window), self->preferences_tab);
+    {
+      empathy_roster_window_show_preferences (
+          EMPATHY_ROSTER_WINDOW (self->window), self->preferences_tab);
 
-  if (!self->start_hidden)
-    empathy_window_present (GTK_WINDOW (self->window));
+      self->show_preferences = FALSE;
+    }
+  else
+    {
+      if (!self->start_hidden)
+        empathy_window_present (GTK_WINDOW (self->window));
+    }
 
   /* Display the accounts dialog if needed */
   tp_proxy_prepare_async (self->account_manager, NULL,
